@@ -467,10 +467,10 @@ setMethod("anova", signature(object = "lmer"),
                                 check.names = FALSE)
               class(val) <- c("anova", class(val))
               attr(val, "heading") <-
-                  c(header, "", "Models:",
+                  c(header, "Models:",
                     paste(names(mods),
                           unlist(lapply(lapply(calls, "[[", "formula"), deparse)),
-                          sep = ": "),"")
+                          sep = ": "))
               return(val)
           } else {
               foo <- object
@@ -651,6 +651,9 @@ setMethod("fitted", signature(object = "lmer"),
 setMethod("residuals", signature(object = "lmer"),
           function(object, ...) object@residuals)
 
+setMethod("resid", signature(object = "lmer"),
+          function(object, ...) do.call("residuals", c(list(object), list(...))))
+
 setMethod("coef", signature(object = "lmer"),
           function(object, ...)
       {
@@ -700,4 +703,8 @@ setMethod("plot", signature(x = "lmer.ranef"),
           })
       })
 
+setMethod("with", signature(data = "lmer"),
+          function(data, expr, ...) {
+          lst <- c(list(. = data), data@flist, eval(data@call$data))
+          eval(substitute(expr), lst[unique(names(lst))])})
 
